![Pypi](https://img.shields.io/pypi/v/django-table-permissions?style=flat-square)
![Python](https://img.shields.io/pypi/pyversions/django-table-permissions?style=flat-square)
![Django](https://img.shields.io/badge/Django-4.0%7C4.1%7C4.2%7C5.0-green)


# Django Table Permissions

Display django permissions in a user friendly, translatable and customizable widget..

## Installation

You can install django-table-permissions with pip by typing:

    pip install django-table-permissions

Or with poetry by typing::

    poetry add django-table-permissions

Or manually by downloading a tarball and typing::

    python setup.py install

## Settings
